@@ -4,10 +4,12 @@ use Moose;
 # ABSTRACT: An plugin bundle for all distributions by WATERKIP
 # KEYWORDS: author bundle distribution tool
 
-use Moose::Util::TypeConstraints qw(enum);
+use Moose::Util::TypeConstraints qw(enum subtype where);
 use List::Util qw(uniq any first);
 use namespace::autoclean;
 
+our $VERSION = '1.3';
+
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
     'Dist::Zilla::Role::PluginBundle::PluginRemover' => { -version => '0.103' },
@@ -55,8 +57,8 @@ around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
     sort(uniq(
             $self->$orig(@_),
-            qw(LICENCE LICENSE CONTRIBUTING Changes CHANGES ppport.h INSTALL
-            Makefile.PL cpanfile README README.md Build.PL)
+            qw(LICENCE LICENSE CONTRIBUTING ppport.h INSTALL
+            Makefile.PL cpanfile README Build.PL)
     ));
 };
 
@@ -74,7 +76,15 @@ has fake_release => (
     is => 'ro', isa => 'Bool',
     init_arg => undef,
     lazy => 1,
-    default => sub { $ENV{FAKE_RELEASE} || $_[0]->payload->{fake_release} // 0 },
+    default => sub { $ENV{FAKE_RELEASE} // $_[0]->payload->{fake_release} // 0 },
+);
+
+has changes_version_columns => (
+    is       => 'ro',
+    isa      => subtype('Int', where { $_ > 0 && $_ < 20 }),
+    init_arg => undef,
+    lazy     => 1,
+    default => sub { $_[0]->payload->{changes_version_columns} // 10 },
 );
 
 my @network_plugins = qw(
@@ -95,6 +105,12 @@ sub _warn_me {
     warn(sprintf("[\@Author::WATERKIP]  %s\n", $msg));
 }
 
+
+sub commit_files_after_release {
+    grep { -e } sort(uniq('README.md', 'README.pod', 'Changes', shift->copy_files_from_release));
+}
+
+
 my %removed;
 
 sub configure {
@@ -136,11 +152,12 @@ sub configure {
         qw(Readme ExtraTests ExecDir ShareDir MakeMaker Manifest
            TestRelease PodWeaver),
 
-        [ 'AutoPrereqs' => { skip => [qw(^perl$ ^namespace::autoclean$ ^Moose$)]}],
+        [ 'AutoPrereqs' => { skip => [qw(^perl$ ^namespace::autoclean$)]}],
         [ 'Prereqs::AuthorDeps' => { ':version' => '0.006' } ],
         [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         ['CPANFile'],
-
+        ['Repository'],
+        ['ConfirmRelease'],
 
 #        [ 'PrereqsClean'],
 
@@ -173,6 +190,27 @@ sub configure {
         push @plugins, 'BlockRelease';
     }
 
+    # plugins to do with calculating, munging, incrementing versions
+    $self->add_bundle('@Git::VersionManager' => {
+        'RewriteVersion::Transitional.global' => 1,
+        'RewriteVersion::Transitional.fallback_version_provider' => 'Git::NextVersion',
+        'RewriteVersion::Transitional.version_regexp' => '^v([\d._]+)(-TRIAL)?$',
+
+        # for first Git::Commit
+        commit_files_after_release => [ $self->commit_files_after_release ],
+        # because of [Git::Check], only files copied from the release would be added -- there is nothing else
+        # hanging around in the current directory
+        'release snapshot.add_files_in' => ['.'],
+        'release snapshot.commit_msg' => '%N-%v%t%n%n%c',
+
+        'Git::Tag.tag_message' => 'v%v%t',
+
+        'BumpVersionAfterRelease::Transitional.global' => 1,
+
+        'NextRelease.:version' => '5.033',
+        'NextRelease.time_zone' => 'UTC',
+        'NextRelease.format' => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T',
+    });
     $self->add_plugins(@plugins);
 
 }
@@ -191,7 +229,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.1
+version 1.3
 
 =head1 SYNOPSIS
 
